lists.arthurdejong.org
RSS feed

nss-pam-ldapd commit: r1876 - nss-pam-ldapd/nss

[Date Prev][Date Next] [Thread Prev][Thread Next]

nss-pam-ldapd commit: r1876 - nss-pam-ldapd/nss



Author: arthur
Date: Sun Dec 23 20:56:29 2012
New Revision: 1876
URL: http://arthurdejong.org/viewvc/nss-pam-ldapd?revision=1876&view=revision

Log:
merge NSS_BYNAME and NSS_BYINT32 into NSS_BYGEN and rename to NSS_GETONE

Modified:
   nss-pam-ldapd/nss/aliases.c
   nss-pam-ldapd/nss/common.h
   nss-pam-ldapd/nss/ethers.c
   nss-pam-ldapd/nss/group.c
   nss-pam-ldapd/nss/hosts.c
   nss-pam-ldapd/nss/networks.c
   nss-pam-ldapd/nss/passwd.c
   nss-pam-ldapd/nss/protocols.c
   nss-pam-ldapd/nss/rpc.c
   nss-pam-ldapd/nss/services.c
   nss-pam-ldapd/nss/shadow.c

Modified: nss-pam-ldapd/nss/aliases.c
==============================================================================
--- nss-pam-ldapd/nss/aliases.c Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/aliases.c Sun Dec 23 20:56:29 2012        (r1876)
@@ -53,7 +53,8 @@
                                         char *buffer, size_t buflen,
                                         int *errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_ALIAS_BYNAME, name,
+  NSS_GETONE(NSLCD_ACTION_ALIAS_BYNAME,
+             WRITE_STRING(fp, name),
              read_aliasent(fp, result, buffer, buflen, errnop));
 }
 

Modified: nss-pam-ldapd/nss/common.h
==============================================================================
--- nss-pam-ldapd/nss/common.h  Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/common.h  Sun Dec 23 20:56:29 2012        (r1876)
@@ -107,7 +107,7 @@
    the result structure, the user buffer with length and the
    errno to return. This macro should be called through some of
    the customized ones below. */
-#define NSS_BYGEN(action, writefn, readfn)                                  \
+#define NSS_GETONE(action, writefn, readfn)                                 \
   TFILE *fp;                                                                \
   int32_t tmpint32;                                                         \
   nss_status_t retv;                                                        \
@@ -127,16 +127,6 @@
   }                                                                         \
   return retv;
 
-/* This macro can be used to generate a get..byname() function
-   body. */
-#define NSS_BYNAME(action, name, readfn)                                    \
-  NSS_BYGEN(action, WRITE_STRING(fp, name), readfn)
-
-/* This macro can be used to generate a get..by..() function
-   body where the value should be passed as an int32_t. */
-#define NSS_BYINT32(action, val, readfn)                                    \
-  NSS_BYGEN(action, WRITE_INT32(fp, val), readfn)
-
 /* This macro generates a simple setent() function body. This closes any
    open streams so that NSS_GETENT() can open a new file. */
 #define NSS_SETENT(fp)                                                      \

Modified: nss-pam-ldapd/nss/ethers.c
==============================================================================
--- nss-pam-ldapd/nss/ethers.c  Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/ethers.c  Sun Dec 23 20:56:29 2012        (r1876)
@@ -49,7 +49,8 @@
                                     struct etherent *result, char *buffer,
                                     size_t buflen, int *errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_ETHER_BYNAME, name,
+  NSS_GETONE(NSLCD_ACTION_ETHER_BYNAME,
+             WRITE_STRING(fp, name),
              read_etherent(fp, result, buffer, buflen, errnop));
 }
 
@@ -58,9 +59,9 @@
                                     struct etherent *result, char *buffer,
                                     size_t buflen, int *errnop)
 {
-  NSS_BYGEN(NSLCD_ACTION_ETHER_BYETHER,
-            WRITE(fp, addr, sizeof(uint8_t[6])),
-            read_etherent(fp, result, buffer, buflen, errnop));
+  NSS_GETONE(NSLCD_ACTION_ETHER_BYETHER,
+             WRITE(fp, addr, sizeof(uint8_t[6])),
+             read_etherent(fp, result, buffer, buflen, errnop));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -153,8 +154,8 @@
 /* map a hostname to the corresponding ethernet address */
 static nss_status_t ethers_gethostton(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYNAME(NSLCD_ACTION_ETHER_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_ETHER_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.name),
              read_result(fp, args, 0));
 }
 
@@ -162,9 +163,9 @@
 static nss_status_t ethers_getntohost(nss_backend_t UNUSED(*be), void *args)
 {
   struct ether_addr *addr = (struct ether_addr *)(NSS_ARGS(args)->key.ether);
-  NSS_BYGEN(NSLCD_ACTION_ETHER_BYETHER,
-            WRITE(fp, addr, sizeof(uint8_t[6])),
-            read_result(fp, args, 1));
+  NSS_GETONE(NSLCD_ACTION_ETHER_BYETHER,
+             WRITE(fp, addr, sizeof(uint8_t[6])),
+             read_result(fp, args, 1));
 }
 
 static nss_backend_op_t ethers_ops[] = {

Modified: nss-pam-ldapd/nss/group.c
==============================================================================
--- nss-pam-ldapd/nss/hosts.c   Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/hosts.c   Sun Dec 23 20:56:29 2012        (r1876)
@@ -158,8 +158,8 @@
                                         size_t buflen, int *errnop,
                                         int *h_errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_HOST_BYNAME,
-             name,
+  NSS_GETONE(NSLCD_ACTION_HOST_BYNAME,
+             WRITE_STRING(fp, name),
              read_hostent(fp, result, buffer, buflen, errnop, h_errnop, af, 
0));
 }
 
@@ -187,9 +187,9 @@
                                        char *buffer, size_t buflen,
                                        int *errnop, int *h_errnop)
 {
-  NSS_BYGEN(NSLCD_ACTION_HOST_BYADDR,
-            WRITE_ADDRESS(fp, af, len, addr),
-            read_hostent(fp, result, buffer, buflen, errnop, h_errnop, af, 0));
+  NSS_GETONE(NSLCD_ACTION_HOST_BYADDR,
+             WRITE_ADDRESS(fp, af, len, addr),
+             read_hostent(fp, result, buffer, buflen, errnop, h_errnop, af, 
0));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -265,18 +265,18 @@
 
 static nss_status_t hosts_gethostbyname(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYNAME(NSLCD_ACTION_HOST_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_HOST_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.name),
              read_result(fp, AF_INET, 0, args));
 }
 
 static nss_status_t hosts_gethostbyaddr(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYGEN(NSLCD_ACTION_HOST_BYADDR,
-            WRITE_ADDRESS(fp, NSS_ARGS(args)->key.hostaddr.type,
-                          NSS_ARGS(args)->key.hostaddr.len,
-                          NSS_ARGS(args)->key.hostaddr.addr),
-            read_result(fp, NSS_ARGS(args)->key.hostaddr.type, 0, args));
+  NSS_GETONE(NSLCD_ACTION_HOST_BYADDR,
+             WRITE_ADDRESS(fp, NSS_ARGS(args)->key.hostaddr.type,
+                           NSS_ARGS(args)->key.hostaddr.len,
+                           NSS_ARGS(args)->key.hostaddr.addr),
+             read_result(fp, NSS_ARGS(args)->key.hostaddr.type, 0, args));
 }
 
 static nss_status_t hosts_sethostent(nss_backend_t *be, void UNUSED(*args))

Modified: nss-pam-ldapd/nss/networks.c
==============================================================================
--- nss-pam-ldapd/nss/networks.c        Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/networks.c        Sun Dec 23 20:56:29 2012        (r1876)
@@ -118,8 +118,8 @@
                                       size_t buflen, int *errnop,
                                       int *h_errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_NETWORK_BYNAME,
-             name,
+  NSS_GETONE(NSLCD_ACTION_NETWORK_BYNAME,
+             WRITE_STRING(fp, name),
              read_netent(fp, result, buffer, buflen, errnop, h_errnop));
 }
 
@@ -130,9 +130,9 @@
                                       size_t buflen, int *errnop,
                                       int *h_errnop)
 {
-  NSS_BYGEN(NSLCD_ACTION_NETWORK_BYADDR,
-            WRITE_ADDRESS(fp, addr),
-            read_netent(fp, result, buffer, buflen, errnop, h_errnop));
+  NSS_GETONE(NSLCD_ACTION_NETWORK_BYADDR,
+             WRITE_ADDRESS(fp, addr),
+             read_netent(fp, result, buffer, buflen, errnop, h_errnop));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -194,16 +194,16 @@
 
 static nss_status_t networks_getnetbyname(nss_backend_t UNUSED(*be), void 
*args)
 {
-  NSS_BYNAME(NSLCD_ACTION_NETWORK_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_NETWORK_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.name),
              read_result(fp, args));
 }
 
 static nss_status_t networks_getnetbyaddr(nss_backend_t UNUSED(*be), void 
*args)
 {
-  NSS_BYGEN(NSLCD_ACTION_NETWORK_BYADDR,
-            WRITE_ADDRESS(fp, NSS_ARGS(args)->key.netaddr.net),
-            read_result(fp, args));
+  NSS_GETONE(NSLCD_ACTION_NETWORK_BYADDR,
+             WRITE_ADDRESS(fp, NSS_ARGS(args)->key.netaddr.net),
+             read_result(fp, args));
 }
 
 static nss_status_t networks_setnetent(nss_backend_t *be, void UNUSED(*args))

Modified: nss-pam-ldapd/nss/passwd.c
==============================================================================
--- nss-pam-ldapd/nss/passwd.c  Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/passwd.c  Sun Dec 23 20:56:29 2012        (r1876)
@@ -57,8 +57,8 @@
 nss_status_t _nss_ldap_getpwnam_r(const char *name, struct passwd *result,
                                   char *buffer, size_t buflen, int *errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_PASSWD_BYNAME,
-             name,
+  NSS_GETONE(NSLCD_ACTION_PASSWD_BYNAME,
+             WRITE_STRING(fp, name),
              read_passwd(fp, result, buffer, buflen, errnop));
 }
 
@@ -66,9 +66,9 @@
 nss_status_t _nss_ldap_getpwuid_r(uid_t uid, struct passwd *result,
                                   char *buffer, size_t buflen, int *errnop)
 {
-  NSS_BYINT32(NSLCD_ACTION_PASSWD_BYUID,
-              uid,
-              read_passwd(fp, result, buffer, buflen, errnop));
+  NSS_GETONE(NSLCD_ACTION_PASSWD_BYUID,
+             WRITE_INT32(fp, uid),
+             read_passwd(fp, result, buffer, buflen, errnop));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -119,16 +119,16 @@
 
 static nss_status_t passwd_getpwnam(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYNAME(NSLCD_ACTION_PASSWD_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_PASSWD_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.name),
              read_result(fp, args));
 }
 
 static nss_status_t passwd_getpwuid(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYINT32(NSLCD_ACTION_PASSWD_BYUID,
-              NSS_ARGS(args)->key.uid,
-              read_result(fp, args));
+  NSS_GETONE(NSLCD_ACTION_PASSWD_BYUID,
+             WRITE_INT32(fp, NSS_ARGS(args)->key.uid),
+             read_result(fp, args));
 }
 
 /* open a connection to the nslcd and write the request */

Modified: nss-pam-ldapd/nss/protocols.c
==============================================================================
--- nss-pam-ldapd/nss/protocols.c       Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/protocols.c       Sun Dec 23 20:56:29 2012        (r1876)
@@ -51,8 +51,8 @@
                                         char *buffer, size_t buflen,
                                         int *errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_PROTOCOL_BYNAME,
-             name,
+  NSS_GETONE(NSLCD_ACTION_PROTOCOL_BYNAME,
+             WRITE_STRING(fp, name),
              read_protoent(fp, result, buffer, buflen, errnop));
 }
 
@@ -61,9 +61,9 @@
                                           char *buffer, size_t buflen,
                                           int *errnop)
 {
-  NSS_BYINT32(NSLCD_ACTION_PROTOCOL_BYNUMBER,
-              number,
-              read_protoent(fp, result, buffer, buflen, errnop));
+  NSS_GETONE(NSLCD_ACTION_PROTOCOL_BYNUMBER,
+             WRITE_INT32(fp, number),
+             read_protoent(fp, result, buffer, buflen, errnop));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -119,16 +119,16 @@
 
 static nss_status_t protocols_getprotobyname(nss_backend_t UNUSED(*be), void 
*args)
 {
-  NSS_BYNAME(NSLCD_ACTION_PROTOCOL_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_PROTOCOL_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.name),
              read_result(fp, args));
 }
 
 static nss_status_t protocols_getprotobynumber(nss_backend_t UNUSED(*be), void 
*args)
 {
-  NSS_BYINT32(NSLCD_ACTION_PROTOCOL_BYNUMBER,
-              NSS_ARGS(args)->key.number,
-              read_result(fp, args));
+  NSS_GETONE(NSLCD_ACTION_PROTOCOL_BYNUMBER,
+             WRITE_INT32(fp, NSS_ARGS(args)->key.number),
+             read_result(fp, args));
 }
 
 static nss_status_t protocols_setprotoent(nss_backend_t *be, void 
UNUSED(*args))

Modified: nss-pam-ldapd/nss/rpc.c
==============================================================================
--- nss-pam-ldapd/nss/rpc.c     Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/rpc.c     Sun Dec 23 20:56:29 2012        (r1876)
@@ -50,8 +50,8 @@
                                       struct rpcent *result, char *buffer,
                                       size_t buflen, int *errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_RPC_BYNAME,
-             name,
+  NSS_GETONE(NSLCD_ACTION_RPC_BYNAME,
+             WRITE_STRING(fp, name),
              read_rpcent(fp, result, buffer, buflen, errnop));
 }
 
@@ -60,9 +60,9 @@
                                         char *buffer, size_t buflen,
                                         int *errnop)
 {
-  NSS_BYINT32(NSLCD_ACTION_RPC_BYNUMBER,
-              number,
-              read_rpcent(fp, result, buffer, buflen, errnop));
+  NSS_GETONE(NSLCD_ACTION_RPC_BYNUMBER,
+             WRITE_INT32(fp, number),
+             read_rpcent(fp, result, buffer, buflen, errnop));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -118,16 +118,16 @@
 
 static nss_status_t rpc_getrpcbyname(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYNAME(NSLCD_ACTION_RPC_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_RPC_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.name),
              read_result(fp, args));
 }
 
 static nss_status_t rpc_getrpcbynumber(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYINT32(NSLCD_ACTION_RPC_BYNUMBER,
-              NSS_ARGS(args)->key.number,
-              read_result(fp, args));
+  NSS_GETONE(NSLCD_ACTION_RPC_BYNUMBER,
+             WRITE_INT32(fp, NSS_ARGS(args)->key.number),
+             read_result(fp, args));
 }
 
 static nss_status_t rpc_setrpcent(nss_backend_t *be, void UNUSED(*args))

Modified: nss-pam-ldapd/nss/services.c
==============================================================================
--- nss-pam-ldapd/nss/services.c        Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/services.c        Sun Dec 23 20:56:29 2012        (r1876)
@@ -54,10 +54,10 @@
                                        struct servent *result, char *buffer,
                                        size_t buflen, int *errnop)
 {
-  NSS_BYGEN(NSLCD_ACTION_SERVICE_BYNAME,
-            WRITE_STRING(fp, name);
-            WRITE_STRING(fp, protocol),
-            read_servent(fp, result, buffer, buflen, errnop));
+  NSS_GETONE(NSLCD_ACTION_SERVICE_BYNAME,
+             WRITE_STRING(fp, name);
+             WRITE_STRING(fp, protocol),
+             read_servent(fp, result, buffer, buflen, errnop));
 }
 
 /* get a service entry by port and protocol */
@@ -66,11 +66,11 @@
                                        size_t buflen, int *errnop)
 {
   /* port is already in network byte order */
-  NSS_BYGEN(NSLCD_ACTION_SERVICE_BYNUMBER,
-            tmpint32 = ntohs(port);
-            WRITE_INT32(fp, tmpint32);
-            WRITE_STRING(fp, protocol),
-            read_servent(fp, result, buffer, buflen, errnop));
+  NSS_GETONE(NSLCD_ACTION_SERVICE_BYNUMBER,
+             tmpint32 = ntohs(port);
+             WRITE_INT32(fp, tmpint32);
+             WRITE_STRING(fp, protocol),
+             read_servent(fp, result, buffer, buflen, errnop));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -127,18 +127,18 @@
 
 static nss_status_t services_getservbyname(nss_backend_t UNUSED(*be), void 
*args)
 {
-  NSS_BYGEN(NSLCD_ACTION_SERVICE_BYNAME,
-            WRITE_STRING(fp, NSS_ARGS(args)->key.serv.serv.name);
-            WRITE_STRING(fp, NSS_ARGS(args)->key.serv.proto),
-            read_result(fp, args));
+  NSS_GETONE(NSLCD_ACTION_SERVICE_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.serv.serv.name);
+             WRITE_STRING(fp, NSS_ARGS(args)->key.serv.proto),
+             read_result(fp, args));
 }
 
 static nss_status_t services_getservbyport(nss_backend_t UNUSED(*be), void 
*args)
 {
-  NSS_BYGEN(NSLCD_ACTION_SERVICE_BYNUMBER,
-            WRITE_INT32(fp, ntohs(NSS_ARGS(args)->key.serv.serv.port));
-            WRITE_STRING(fp, NSS_ARGS(args)->key.serv.proto),
-            read_result(fp, args));
+  NSS_GETONE(NSLCD_ACTION_SERVICE_BYNUMBER,
+             WRITE_INT32(fp, ntohs(NSS_ARGS(args)->key.serv.serv.port));
+             WRITE_STRING(fp, NSS_ARGS(args)->key.serv.proto),
+             read_result(fp, args));
 }
 
 static nss_status_t services_setservent(nss_backend_t *be, void UNUSED(*args))

Modified: nss-pam-ldapd/nss/shadow.c
==============================================================================
--- nss-pam-ldapd/nss/shadow.c  Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/shadow.c  Sun Dec 23 20:56:29 2012        (r1876)
@@ -55,8 +55,8 @@
 nss_status_t _nss_ldap_getspnam_r(const char *name, struct spwd *result,
                                   char *buffer, size_t buflen, int *errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_SHADOW_BYNAME,
-             name,
+  NSS_GETONE(NSLCD_ACTION_SHADOW_BYNAME,
+             WRITE_STRING(fp, name),
              read_spwd(fp, result, buffer, buflen, errnop));
 }
 
@@ -125,8 +125,8 @@
 
 static nss_status_t shadow_getspnam(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYNAME(NSLCD_ACTION_SHADOW_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_SHADOW_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key. name),
              read_result(fp, args));
 }
 
--- nss-pam-ldapd/nss/group.c   Sun Dec 23 20:38:46 2012        (r1875)
+++ nss-pam-ldapd/nss/group.c   Sun Dec 23 20:56:29 2012        (r1876)
@@ -118,8 +118,8 @@
 nss_status_t _nss_ldap_getgrnam_r(const char *name, struct group *result,
                                   char *buffer, size_t buflen, int *errnop)
 {
-  NSS_BYNAME(NSLCD_ACTION_GROUP_BYNAME,
-             name,
+  NSS_GETONE(NSLCD_ACTION_GROUP_BYNAME,
+             WRITE_STRING(fp, name),
              read_group(fp, result, buffer, buflen, errnop));
 }
 
@@ -127,9 +127,9 @@
 nss_status_t _nss_ldap_getgrgid_r(gid_t gid, struct group *result,
                                   char *buffer, size_t buflen, int *errnop)
 {
-  NSS_BYINT32(NSLCD_ACTION_GROUP_BYGID,
-              gid,
-              read_group(fp, result, buffer, buflen, errnop));
+  NSS_GETONE(NSLCD_ACTION_GROUP_BYGID,
+             WRITE_INT32(fp, gid),
+             read_group(fp, result, buffer, buflen, errnop));
 }
 
 /* thread-local file pointer to an ongoing request */
@@ -172,13 +172,13 @@
                                       gid_t **groupsp, long int limit,
                                       int *errnop)
 {
 /* temporarily map the buffer and buflen names so the check in NSS_BYNAME
    for validity of the buffer works (renaming the parameters may cause
    confusion) */
 #define buffer groupsp
 #define buflen *size
-  NSS_BYNAME(NSLCD_ACTION_GROUP_BYMEMBER,
-             user,
+  NSS_GETONE(NSLCD_ACTION_GROUP_BYMEMBER,
+             WRITE_STRING(fp, user),
              read_gids(fp, skipgroup, start, size, groupsp, limit, errnop));
 #undef buffer
 #undef buflen
@@ -217,16 +217,16 @@
 
 static nss_status_t group_getgrnam(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYNAME(NSLCD_ACTION_GROUP_BYNAME,
-             NSS_ARGS(args)->key.name,
+  NSS_GETONE(NSLCD_ACTION_GROUP_BYNAME,
+             WRITE_STRING(fp, NSS_ARGS(args)->key.name),
              read_result(fp, args));
 }
 
 static nss_status_t group_getgrgid(nss_backend_t UNUSED(*be), void *args)
 {
-  NSS_BYINT32(NSLCD_ACTION_GROUP_BYGID,
-              NSS_ARGS(args)->key.gid,
-              read_result(fp, args));
+  NSS_GETONE(NSLCD_ACTION_GROUP_BYGID,
+             WRITE_INT32(fp, NSS_ARGS(args)->key.gid),
+             read_result(fp, args));
 }
 
 static nss_status_t group_setgrent(nss_backend_t *be, void UNUSED(*args))
@@ -250,12 +250,11 @@
   struct nss_groupsbymem *argp = (struct nss_groupsbymem *)args;
   long int start = (long int)argp->numgids;
   gid_t skipgroup = (start > 0) ? argp->gid_array[0] : (gid_t)-1;
-  NSS_BYNAME(NSLCD_ACTION_GROUP_BYMEMBER,
-             argp->username,
+  NSS_GETONE(NSLCD_ACTION_GROUP_BYMEMBER,
+             WRITE_STRING(fp, argp->username),
              read_gids(fp, skipgroup, &start, NULL, (gid_t **)&argp->gid_array,
                        argp->maxgids, &NSS_ARGS(args)->erange);
-             argp->numgids = (int)start;
-      );
+             argp->numgids = (int)start);
 }
 
 static nss_backend_op_t group_ops[] = {
@@ -172,13 +172,13 @@
                                       int *errnop)
 {
-/* temporarily map the buffer and buflen names so the check in NSS_BYNAME
+/* temporarily map the buffer and buflen names so the check in NSS_GETONE
    for validity of the buffer works (renaming the parameters may cause
    confusion) */

Modified: nss-pam-ldapd/nss/hosts.c
==============================================================================
-- 
To unsubscribe send an email to
nss-pam-ldapd-commits-unsubscribe@lists.arthurdejong.org or see
http://lists.arthurdejong.org/nss-pam-ldapd-commits/